'Fleet'The component of the operating model that controls fishing dynamics
NameName of the Fleet object. Single value. Character string.
NameName of the Fleet object. Single value. Character string.
nyearsThe number of years for the historical 'spool-up' simulation. Single value. Positive integer
CurrentYrThe current calendar year (final year) of the historical simulations (eg 2011). Single value. Positive integer
EffYearsYears representing join-points (vertices) of time-varying effort. Vector. Non-negative real numbers
EffLowerLower bound on relative effort corresponding to EffYears. Vector. Non-negative real numbers
EffUpperUpper bound on relative effort corresponding to EffYears. Vector. Non-negative real numbers
EsdAdditional inter-annual variability in fishing mortality rate. Uniform distribution lower and upper bounds. Non-negative real numbers
qincAverage percentage change in fishing efficiency (applicable only to forward projection and input controls). Uniform distribution lower and upper bounds. Non-negative real numbers
qcvInter-annual variability in fishing efficiency (applicable only to forward projection and input controls). Uniform distribution lower and upper bounds. Non-negative real numbers
L5Shortest length corresponding to 5 percent vulnerability. Uniform distribution lower and upper bounds. Positive real numbers
LFSShortest length that is fully vulnerable to fishing. Uniform distribution lower and upper bounds. Positive real numbers
VmaxlenThe vulnerability of fish at Stock@Linf. Uniform
distribution lower and upper bounds. Fraction
isRelSelectivity parameters in units of size-of-maturity (or absolute eg cm). Single value. Boolean
LR5Shortest length corresponding at 5 percent retention. Uniform distribution lower and upper bounds. Non-negative real numbers
LFRShortest length that is fully retained. Uniform distribution lower and upper bounds. Non-negative real numbers
RmaxlenThe retention of fish at Stock@Linf. Uniform
distribution lower and upper bounds. Non-negative real numbers
DRDiscard rate - the fraction of caught fish that are discarded. Uniform distribution lower and upper bounds. Fraction
Spat_targDistribution of fishing in relation to spatial biomass: fishing distribution is proportional to B^Spat_targ. Uniform distribution lower and upper bounds. Real numbers
MPAIs Area 1 currently closed (TRUE) or open (FALSE)? Defaults to FALSE
MiscMiscellaneous list for bio-economic parameters
Objects can be created by calls of the form new('Fleet')
# NOT RUN {
showClass('Fleet')
# }
Run the code above in your browser using DataLab