Learn R Programming

MSEtool (version 3.0.0)

Obs-class: Class 'Obs'

Description

An operating model component that controls the observation model

Arguments

Slots

Name

The name of the observation model object. Single value. Character string.

Name

The name of the Observation error object. Single value. Character string.

Cobs

Log-normal catch observation error expressed as a coefficient of variation. Uniform distribution lower and upper bounds. Non-negative real numbers

Cbiascv

Log-normal coefficient of variation controlling the sampling of bias in catch observations for each simulation. Single value. Non-negative real number

CAA_nsamp

Number of catch-at-age observation per time step. Uniform distribution lower and upper bounds. Positive real numbers

CAA_ESS

Effective sample size (independent age draws) of the multinomial catch-at-age observation error model. Uniform distribution lower and upper bounds. Positive integers

CAL_nsamp

Number of catch-at-length observation per time step. Uniform distribution lower and upper bounds. Positive integers

CAL_ESS

Effective sample size (independent length draws) of the multinomial catch-at-length observation error model. Uniform distribution lower and upper bounds. Positive integers

Iobs

Observation error in the relative abundance indices expressed as a coefficient of variation. Uniform distribution lower and upper bounds. Positive real numbers

Btobs

Log-normal coefficient of variation controlling error in observations of current stock biomass among years. Uniform distribution lower and upper bounds. Positive real numbers

Btbiascv

Uniform-log bounds for sampling persistent bias in current stock biomass. Uniform-log distribution lower and upper bounds. Positive real numbers

beta

A parameter controlling hyperstability/hyperdepletion where values below 1 lead to hyperstability (an index that decreases slower than true abundance) and values above 1 lead to hyperdepletion (an index that decreases more rapidly than true abundance). Uniform distribution lower and upper bounds. Positive real numbers

LenMbiascv

Log-normal coefficient of variation for sampling persistent bias in length at 50 percent maturity. Single value. Positive real numbers

Mbiascv

Log-normal coefficient of variation for sampling persistent bias in observed natural mortality rate. Single value. Positive real number

Kbiascv

Log-normal coefficient of variation for sampling persistent bias in observed growth parameter K. Single value. Positive real number

t0biascv

Log-normal coefficient of variation for sampling persistent bias in observed t0. Single value. Positive real number

Linfbiascv

Log-normal coefficient of variation for sampling persistent bias in observed maximum length. Single value. Positive real number

LFCbiascv

Log-normal coefficient of variation for sampling persistent bias in observed length at first capture. Single value. Positive real number

LFSbiascv

Log-normal coefficient of variation for sampling persistent bias in length-at-full selection. Single value. Positive real number

FMSY_Mbiascv

Log-normal coefficient of variation for sampling persistent bias in FMSY/M. Single value. Positive real number

BMSY_B0biascv

Log-normal coefficient of variation for sampling persistent bias in BMSY relative to unfished. Single value. Positive real number

Irefbiascv

Log-normal coefficient of variation for sampling persistent bias in relative abundance index at BMSY. Single value. Positive real number

Brefbiascv

Log-normal coefficient of variation for sampling persistent bias in BMSY. Single value. Positive real number

Crefbiascv

Log-normal coefficient of variation for sampling persistent bias in MSY. Single value. Positive real number

Dbiascv

Log-normal coefficient of variation for sampling persistent bias in stock depletion. Single value. Positive real number

Dobs

Log-normal coefficient of variation controlling error in observations of stock depletion among years. Uniform distribution lower and upper bounds. Positive real numbers

hbiascv

Log-normal coefficient of variation for sampling persistent bias in steepness. Single value. Positive real number

Recbiascv

Log-normal coefficient of variation for sampling persistent bias in recent recruitment strength. Uniform distribution lower and upper bounds. Positive real numbers

sigmaRbiascv

Log-normal coefficient of variation for sampling persistent bias in recruitment variability. Single value. Positive real number

Eobs

Log-normal effort observation error expressed as a coefficient of variation. Uniform distribution lower and upper bounds. Non-negative real numbers

Ebiascv

Log-normal coefficient of variation controlling the sampling of bias in effort observations for each simulation. Single value. Non-negative real number

Objects from the Class

Objects can be created by calls of the form new('Obs')

Examples

Run this code
# NOT RUN {
showClass('Obs')

# }

Run the code above in your browser using DataLab