'Obs'An operating model component that controls the observation model
NameThe name of the observation model object. Single value. Character string.
NameThe name of the Observation error object. Single value. Character string.
CobsLog-normal catch observation error expressed as a coefficient of variation. Uniform distribution lower and upper bounds. Non-negative real numbers
CbiascvLog-normal coefficient of variation controlling the sampling of bias in catch observations for each simulation. Single value. Non-negative real number
CAA_nsampNumber of catch-at-age observation per time step. Uniform distribution lower and upper bounds. Positive real numbers
CAA_ESSEffective sample size (independent age draws) of the multinomial catch-at-age observation error model. Uniform distribution lower and upper bounds. Positive integers
CAL_nsampNumber of catch-at-length observation per time step. Uniform distribution lower and upper bounds. Positive integers
CAL_ESSEffective sample size (independent length draws) of the multinomial catch-at-length observation error model. Uniform distribution lower and upper bounds. Positive integers
IobsObservation error in the relative abundance indices expressed as a coefficient of variation. Uniform distribution lower and upper bounds. Positive real numbers
BtobsLog-normal coefficient of variation controlling error in observations of current stock biomass among years. Uniform distribution lower and upper bounds. Positive real numbers
BtbiascvUniform-log bounds for sampling persistent bias in current stock biomass. Uniform-log distribution lower and upper bounds. Positive real numbers
betaA parameter controlling hyperstability/hyperdepletion where values below 1 lead to hyperstability (an index that decreases slower than true abundance) and values above 1 lead to hyperdepletion (an index that decreases more rapidly than true abundance). Uniform distribution lower and upper bounds. Positive real numbers
LenMbiascvLog-normal coefficient of variation for sampling persistent bias in length at 50 percent maturity. Single value. Positive real numbers
MbiascvLog-normal coefficient of variation for sampling persistent bias in observed natural mortality rate. Single value. Positive real number
KbiascvLog-normal coefficient of variation for sampling persistent bias in observed growth parameter K. Single value. Positive real number
t0biascvLog-normal coefficient of variation for sampling persistent bias in observed t0. Single value. Positive real number
LinfbiascvLog-normal coefficient of variation for sampling persistent bias in observed maximum length. Single value. Positive real number
LFCbiascvLog-normal coefficient of variation for sampling persistent bias in observed length at first capture. Single value. Positive real number
LFSbiascvLog-normal coefficient of variation for sampling persistent bias in length-at-full selection. Single value. Positive real number
FMSY_MbiascvLog-normal coefficient of variation for sampling persistent bias in FMSY/M. Single value. Positive real number
BMSY_B0biascvLog-normal coefficient of variation for sampling persistent bias in BMSY relative to unfished. Single value. Positive real number
IrefbiascvLog-normal coefficient of variation for sampling persistent bias in relative abundance index at BMSY. Single value. Positive real number
BrefbiascvLog-normal coefficient of variation for sampling persistent bias in BMSY. Single value. Positive real number
CrefbiascvLog-normal coefficient of variation for sampling persistent bias in MSY. Single value. Positive real number
DbiascvLog-normal coefficient of variation for sampling persistent bias in stock depletion. Single value. Positive real number
DobsLog-normal coefficient of variation controlling error in observations of stock depletion among years. Uniform distribution lower and upper bounds. Positive real numbers
hbiascvLog-normal coefficient of variation for sampling persistent bias in steepness. Single value. Positive real number
RecbiascvLog-normal coefficient of variation for sampling persistent bias in recent recruitment strength. Uniform distribution lower and upper bounds. Positive real numbers
sigmaRbiascvLog-normal coefficient of variation for sampling persistent bias in recruitment variability. Single value. Positive real number
EobsLog-normal effort observation error expressed as a coefficient of variation. Uniform distribution lower and upper bounds. Non-negative real numbers
EbiascvLog-normal coefficient of variation controlling the sampling of bias in effort observations for each simulation. Single value. Non-negative real number
Objects can be created by calls of the form
new('Obs')
# NOT RUN {
showClass('Obs')
# }
Run the code above in your browser using DataLab