Learn R Programming

MSEtool (version 3.0.0)

Stock-class: Class 'Stock'

Description

An operating model component that specifies the parameters of the population dynamics model

Arguments

Slots

Name

The name of the Stock object. Single value. Character string

Name

The name of the Stock object. Single value. Character string

Common_Name

Common name of the species. Character string

Species

Scientific name of the species. Genus and species name. Character string

maxage

The maximum age of individuals that is simulated (there is no 'plus group'). Single value. Positive integer

R0

The magnitude of unfished recruitment. Single value. Positive real number

M

Natural mortality rate. Uniform distribution lower and upper bounds. Positive real number

Msd

Inter-annual variability in natural mortality rate expressed as a coefficient of variation. Uniform distribution lower and upper bounds. Non-negative real numbers

h

Steepness of the stock recruit relationship. Uniform distribution lower and upper bounds. Values from 1/5 to 1

SRrel

Type of stock-recruit relationship. Single value, switch (1) Beverton-Holt (2) Ricker. Integer

Perr

Process error, the CV of log-normal recruitment deviations. Uniform distribution lower and upper bounds. Non-negative real numbers

AC

Auto-correlation in recruitment deviations rec(t)=AC*rec(t-1)+(1-AC)*sigma(t). Uniform distribution lower and upper bounds. Non-negative real numbers

Linf

Maximum length. Uniform distribution lower and upper bounds. Positive real numbers

Linfsd

Inter-annual variability in maximum length expressed as a coefficient of variation. Uniform distribution lower and upper bounds. Non-negative real numbers

K

von Bertalanffy growth parameter k. Uniform distribution lower and upper bounds. Positive real numbers

Ksd

Inter-annual variability in growth parameter k expressed as coefficient of variation. Uniform distribution lower and upper bounds. Non-negative real numbers

t0

von Bertalanffy theoretical age at length zero. Uniform distribution lower and upper bounds. Non-positive real numbers

LenCV

Coefficient of variation of length-at-age (assumed constant for all age classes). Uniform distribution lower and upper bounds. Positive real numbers

L50

Length at 50 percent maturity. Uniform distribution lower and upper bounds. Positive real numbers

L50_95

Length increment from 50 percent to 95 percent maturity. Uniform distribution lower and upper bounds. Positive real numbers

D

Current level of stock depletion SSB(current)/SSB(unfished). Uniform distribution lower and upper bounds. Fraction

a

Length-weight parameter alpha. Single value. Positive real number

b

Length-weight parameter beta. Single value. Positive real number

Size_area_1

The size of area 1 relative to area 2. Uniform distribution lower and upper bounds. Positive real numbers

Frac_area_1

The fraction of the unfished biomass in stock 1. Uniform distribution lower and upper bounds. Positive real numbers

Prob_staying

The probability of individuals in area 1 remaining in area 1 over the course of one year. Uniform distribution lower and upper bounds. Positive fraction.

Fdisc

Fraction of discarded fish that die. Uniform distribution lower and upper bounds. Non-negative real numbers

A reference to a website or article from which parameters were taken to define the stock object. Single value. Character string.

Objects from the Class

Objects can be created by calls of the form new('Stock')

Examples

Run this code
# NOT RUN {
showClass('Stock')

# }

Run the code above in your browser using DataLab