'Stock'An operating model component that specifies the parameters of the population dynamics model
NameThe name of the Stock object. Single value. Character string
NameThe name of the Stock object. Single value. Character string
Common_NameCommon name of the species. Character string
SpeciesScientific name of the species. Genus and species name. Character string
maxageThe maximum age of individuals that is simulated (there is no 'plus group'). Single value. Positive integer
R0The magnitude of unfished recruitment. Single value. Positive real number
MNatural mortality rate. Uniform distribution lower and upper bounds. Positive real number
MsdInter-annual variability in natural mortality rate expressed as a coefficient of variation. Uniform distribution lower and upper bounds. Non-negative real numbers
hSteepness of the stock recruit relationship. Uniform distribution lower and upper bounds. Values from 1/5 to 1
SRrelType of stock-recruit relationship. Single value, switch (1) Beverton-Holt (2) Ricker. Integer
PerrProcess error, the CV of log-normal recruitment deviations. Uniform distribution lower and upper bounds. Non-negative real numbers
ACAuto-correlation in recruitment deviations rec(t)=AC*rec(t-1)+(1-AC)*sigma(t). Uniform distribution lower and upper bounds. Non-negative real numbers
LinfMaximum length. Uniform distribution lower and upper bounds. Positive real numbers
LinfsdInter-annual variability in maximum length expressed as a coefficient of variation. Uniform distribution lower and upper bounds. Non-negative real numbers
Kvon Bertalanffy growth parameter k. Uniform distribution lower and upper bounds. Positive real numbers
KsdInter-annual variability in growth parameter k expressed as coefficient of variation. Uniform distribution lower and upper bounds. Non-negative real numbers
t0von Bertalanffy theoretical age at length zero. Uniform distribution lower and upper bounds. Non-positive real numbers
LenCVCoefficient of variation of length-at-age (assumed constant for all age classes). Uniform distribution lower and upper bounds. Positive real numbers
L50Length at 50 percent maturity. Uniform distribution lower and upper bounds. Positive real numbers
L50_95Length increment from 50 percent to 95 percent maturity. Uniform distribution lower and upper bounds. Positive real numbers
DCurrent level of stock depletion SSB(current)/SSB(unfished). Uniform distribution lower and upper bounds. Fraction
aLength-weight parameter alpha. Single value. Positive real number
bLength-weight parameter beta. Single value. Positive real number
Size_area_1The size of area 1 relative to area 2. Uniform distribution lower and upper bounds. Positive real numbers
Frac_area_1The fraction of the unfished biomass in stock 1. Uniform distribution lower and upper bounds. Positive real numbers
Prob_stayingThe probability of individuals in area 1 remaining in area 1 over the course of one year. Uniform distribution lower and upper bounds. Positive fraction.
FdiscFraction of discarded fish that die. Uniform distribution lower and upper bounds. Non-negative real numbers
SourceA reference to a website or article from which parameters were taken to define the stock object. Single value. Character string.
Objects can be created by calls of the form
new('Stock')
# NOT RUN {
showClass('Stock')
# }
Run the code above in your browser using DataLab